@@ -1,4 +1,4 @@
-/* Copyright (c) 2000, 2018, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2019, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -188,7 +188,12 @@
 #define FIELD_IS_MARKED                   \
   (1 << 28) /**< Intern: field is marked, \
                  general purpose */
-#define CLUSTERING_FLAG (1U << 29)
+
+/** Field will not be loaded in secondary engine. */
+#define NOT_SECONDARY_FLAG (1 << 29)
+
+#define CLUSTERING_FLAG (1U << 30)
+
 /** @}*/
 
 /**
@@ -252,7 +257,7 @@ static const int PURGE_BITMAPS_TO_LSN = 1;
    @defgroup group_cs_capabilities_flags Capabilities Flags
    @ingroup group_cs
 
-   @brief Values for the capabilities flag bitmask used by @ref PAGE_PROTOCOL
+   @brief Values for the capabilities flag bitmask used by the MySQL protocol
 
    Currently need to fit into 32 bits.
 
@@ -1008,7 +1013,6 @@ bool net_write_command(struct NET *net, unsigned char command,
 bool net_write_packet(struct NET *net, const unsigned char *packet,
                       size_t length);
 unsigned long my_net_read(struct NET *net);
-
 void my_net_set_write_timeout(struct NET *net, unsigned int timeout);
 void my_net_set_read_timeout(struct NET *net, unsigned int timeout);
 void my_net_set_retry_count(struct NET *net, unsigned int retry_count);
